@@ -115,6 +115,12 @@ module BloggerPost
       html.sub(/<#{tag}( .*?>|>).*?<\/#{tag}>/im, '')
     end
 
+    def delete_all_tag(html, tag)
+      html = html.gsub(/<#{tag}( .*?>|>).*?<\/#{tag}>/im, '')
+      html = html.gsub(/<#{tag}( .*?\/>|\/>)/im, '')
+      html
+    end
+
     def delete_first_h1(html)
       delete_first_tag(html, 'h1')
     end
