@@ -156,7 +156,9 @@ module BloggerPost
 
     def clear_cache
       @html = nil
-      File.unlink(cache_filename) unless draft?
+      unless draft?
+        File.unlink(cache_filename) if File.exists?(cache_filename)
+      end
     end
 
     def title
