@@ -13,7 +13,7 @@ module BloggerPost
 
   class ::BloggerPost::Folder
     include ::BloggerPost::Common
-    
+
     attr_reader :entry_list, :name, :title, :search_list
 
     def initialize(entry_list, name, title, is_draft)
@@ -70,7 +70,7 @@ module BloggerPost
       entry.delete
     end
   end
-  
+
   class ElBPApp < ElApp
     include ::BloggerPost::Common
 
@@ -90,7 +90,8 @@ module BloggerPost
       'html'  => :html_mode,
       'bhtml' => :html_mode,
       'rd'    => :rd_mode,
-      'rst'   => :rst_mode
+      'rst'   => :rst_mode,
+      'org'    => :org_mode
     }
 
     SORT_PROMPT = "Sort by: (D)ate (T)itle: "
@@ -123,7 +124,7 @@ module BloggerPost
     # util
 
     def format_date(date)
-      date.strftime(DATE_FORMAT) + "(#{WEEK_DAY[date.wday]})" + date.strftime(TIME_FORMAT)
+      date.strftime(to_external_encode(DATE_FORMAT)) + "(#{to_external_encode(WEEK_DAY[date.wday])})" + date.strftime(TIME_FORMAT)
     end
 
     def cut_string(s, len)
@@ -332,7 +333,7 @@ module BloggerPost
       end
       @current_folder.entry_list.reverse! if reverse
     end
-    
+
     def entrylist_read_search_word
       c = 0
       let(:cursor_in_echo_area, true) do
@@ -443,7 +444,7 @@ module BloggerPost
           n = 1
           @current_folder.entry_list.each do |entry|
             entry_line = ' ' + "%#{@current_folder.entry_list.length.to_s.length}d" % n + ' '
-            entry_line << to_external_encode(format_date(entry.date)) + ' '
+            entry_line << format_date(entry.date) + ' '
             entry_line << to_external_encode(entry.title)
             face = nil
             case entry.status
@@ -594,7 +595,7 @@ module BloggerPost
           erase_buffer
           prev_point = point
           insert_entry_header('Title: ', to_external_encode(entry.title), :bloggerpost_entry_title_face)
-          insert_entry_header('Date: ', to_external_encode(format_date(entry.date)), :bloggerpost_entry_date_face)
+          insert_entry_header('Date: ', format_date(entry.date), :bloggerpost_entry_date_face)
           insert_entry_header('URL: ', entry.url) unless entry.draft?
           insert_entry_header('Style: ', entry.style.style_name)
           insert_entry_header('Tag: ', entry.tag_list.collect {|tag| to_external_encode(tag) }.join(', ')) unless entry.tag_list.empty?
@@ -630,7 +631,7 @@ module BloggerPost
     end
 
     def insert_draft_header(header, content)
-      insert_with_properties(header, [:face, :bloggerpost_draft_header_face, :read_only, true, :front_sticky, true, :rear_nonsticky, true])
+      insert_with_properties(header, [:face, :bloggerpost_draft_header_face, :front_sticky, true, :rear_nonsticky, true])
       insert(content)
       newline
     end
@@ -639,7 +640,7 @@ module BloggerPost
       insert_with_properties(BODY_SEPARATOR, [:face, :bloggerpost_draft_header_separator_face, :read_only, true, :front_sticky, true, :rear_nonsticky, true, :bloggerpost_draft_header_separator, true])
       newline
     end
-    
+
     def make_draft_buffer(edit)
       delete_other_windows
       unless edit
@@ -765,7 +766,7 @@ module BloggerPost
         message("(No changes need to be saved)")
       end
     end
-    
+
     defun(:bloggerpost_draft_save_and_exit, :interactive => true) do
       bloggerpost_draft_save
       bloggerpost_draft_exit
